#
# spec file for package sweep
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sweep
Version:        0.9.3
Release:        pm153.5.8
Summary:        Sound wave editor
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Url:            http://sweep.sourceforge.net/
Source0:         %{name}-%{version}.tar.bz2
Source1:        COPYING
Patch0:         sweep-configure-fix.diff
Patch1:         sweep-desktop-fix.diff
Patch2:         fix_crash_when_using_multiple_threads.diff
Patch3:         fix_linking_against_x11.diff
Patch4:         fix_gui_artefacts.diff
Patch5:         link_with_gmodule.diff
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gtk2-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libtool
BuildRequires:  libvorbis-devel
BuildRequires:  pkgconfig(mad)
BuildRequires:  speex-devel
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Sweep is an editor for sound samples. It operates on files of various
formats such as .wav, .aiff and .au, and has multiple undo/redo levels
and filters. It supports audio filter plugins from the LADSPA project.

%prep
%setup -q
cp %{SOURCE1} .
%patch0
%patch1
%patch2
%patch3
%patch4
%patch5
autoreconf -fi
test -f po/Makevars || mv po/Makevars.template po/Makevars

%build
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
# removed unused files
rm -f %{buildroot}%{_libdir}/sweep/*.a
find %{buildroot} -type f -name "*.la" -delete -print
rm -f %{buildroot}%{_datadir}/gnome/apps/Multimedia/sweep.desktop
# remove development files
rm -rf %{buildroot}%{_includedir}/sweep
%suse_update_desktop_file -i %{name} AudioVideo AudioVideoEditing
%find_lang %{name}


%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README README.ALSA README.i18n TODO
%doc doc/*.txt
%doc %{_mandir}/man?/*
%{_bindir}/sweep
%dir %{_libdir}/sweep
%{_libdir}/sweep/*.so
%{_datadir}/pixmaps/*
%{_datadir}/sweep
%{_datadir}/applications/*.desktop

%changelog
* Fri Aug 25 2017 olaf@aepfle.de
- Remove mad conditional because it is always present
* Sun Oct 26 2014 kieltux@gmail.com
- added patch for crash when using multiple threads
  * fix_crash_when_using_multiple_threads.diff,
    Author: Stepan Golosunov <stepan@golosunov.pp.ru>
- added patch for linking against x11
  * fix_linking_against_x11.diff,
    Author: Alessio Treglia <alessio@debian.org>
* Sat Oct 25 2014 kieltux@gmail.com
- added patch for gui artefacts (ruler position)
  * fix_gui_artefacts.diff,
    Author: Philippe Gauthier
* Sat Oct 25 2014 kieltux@gmail.com
- spec file clean up and add some dependencies
- added patch for undefined reference to symbol 'g_module_build_path'
  * link_with_gmodule.diff,
    Author: Colin Watson <cjwatson@ubuntu.com>
* Fri Jun 19 2009 tiwai@suse.de
- use with macro for mad support
* Mon Apr 14 2008 tiwai@suse.de
- updated to version 0.9.3 (bnc#379101):
  * Fixed bounds checking of mode in speex header (oCERT 2008-002)
  * Fixed bug preventing device dialog being reopened when closed
    via the window manager
* Wed Jun 20 2007 tiwai@suse.de
- clean up spec file, use find_lang
- remove development files to make rpmlint happy
- fix desktop file
* Wed Feb  7 2007 tiwai@suse.de
- updated to version 0.9.2:
  * ALSA is now the default driver.
  * added the "hand tool" for panning the display with inertia
  * can now open multiple files via the gtk file selector
  * implemented accel editing via the usual gtk method
  * added tdb lock override
  * remove support for libsndfile0
  * remove direct flac support as it's supported by libsndfile now
  * added a new splash screen
  * fix segfault when closing windows while others were still loading
  * other bugs addressed and changes made.
* Tue Jan 31 2006 tiwai@suse.de
- updated to version 0.9.1 (maintainance release, fix for alsa
  support)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 tiwai@suse.de
- updated to version 0.9.0.
- remove mad support (to be distributable, sigh...)
* Wed Oct 19 2005 tiwai@suse.de
- updated to version 0.8.4.
- enable ALSA support.
* Wed Oct  5 2005 tiwai@suse.de
- added flac and flac-devel to neededforbuild (required by the new
  libsndfile).
- fix a type-punning warning.
* Wed Sep 15 2004 tiwai@suse.de
- fixed segfault at start (#45381).
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 0.8.3.
  removed tdb, already included in 0.8.3 package.
* Fri Apr 16 2004 tiwai@suse.de
- fixed the type-punning.
- disabled the removal of $RPM_BUILD_ROOT in %%install.
* Thu Jan 29 2004 tiwai@suse.de
- build and link libtdb statically inside sweep package
  to avoid the confliction with samba3.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Sep  1 2003 adrian@suse.de
- fix double menu entries
* Thu Aug 28 2003 tiwai@suse.de
- fixed the strict-alias warnings.
- allow to open the database without locking (for NFS home).
- fixed categories.
* Fri Aug 15 2003 adrian@suse.de
- install desktop file
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jun 20 2003 ro@suse.de
- build with current gettext
* Wed Jun 18 2003 ro@suse.de
- added directory to filelist
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 0.8.2.
* Fri Jun  6 2003 tiwai@suse.de
- removed unused files.
- added some missing files to the filelist.
* Fri Feb  7 2003 tiwai@suse.de
- updated to version 0.8.1.
* Tue Jan 21 2003 tiwai@suse.de
- updated to 0.8.0.
- added libsamplerate and -devel to neededforbuild.
* Thu Jan 16 2003 aj@suse.de
- Fix CPP bugs.
* Fri Nov 29 2002 tiwai@suse.de
- updated to version 0.5.11.
* Wed Nov 27 2002 tiwai@suse.de
- initial version: 0.5.10a.
